%projectile_with_drag
% Model which computes the trajectory of a projectile falling under gravity
% and acted upon by air resistance. "Drag" is modelled by F = k*v^2 where v
% is the speed of the projectile. Drag always opposes motion.
%
% LAST UPDATED by Andy French January 2016

function projectile_with_drag

% Define Inputs

% Define density of fluid /kgm^-3
rho = 1;

%Define cross sectional area of falling object /cm^2. Then convert to m^2
A = 10;
A = A/1e4;

%Drag coefficient
cD = 0.1;

%Gravitational field strength /ms^-2
g = 9.81;

%Initial velocity /ms^-1
u = 30;

%Starting height above horizontal ground (the x axis)
h = 2;

%Initial angle of elevation above the horizontal /degrees. Then convert to
%radians
theta = 45;
theta = theta*pi/180;

%Mass of falling object /kg
m = 0.01;

%Time interval /s
dt = 0.01;

%Maximum number of computation points
N = 1000;

%Fontsize
fsize = 18;

%%

%Calculate kinematic variables t,x,y,vx,vy, ax, ay

%Drag constant k such that drag force is F = k*v^2
k = 0.5*cD*rho*A;

%Initialise variables
n = 1;
tt = 0;
xx = 0;
xx_verlet = 0;
yy_verlet = h;
yy = h;
vvx = u*cos(theta);
vvy = u*sin(theta);
vv = sqrt( vvx^2 + vvy^2 );
aax = -(k/m)*vv*vvx;
aay = -g -(k/m)*vv*vvy;

%Initialise variable stores (vectors)
t = tt;
x = xx;
x_verlet = xx_verlet;
y = yy;
y_verlet = yy_verlet;
vx = vvx;
vy= vvy;
v = vv;
ax = aax;
ay = aay;

%Define stopping criteia
stop_condition = ( (tt>0) && (yy<0)  ) || (n>N);

%Step through time and compute trajectory using a numerical method
while stop_condition == 0
    
    %Update kinematic parameters using Euler's method
    tt = tt + dt;
    vvx = vvx + aax*dt;
    vvy = vvy + aay*dt;
    vv = sqrt( vvx^2 + vvy^2 );
    xx = xx + vvx*dt;
    yy = yy + vvy*dt;
    xx_verlet = xx_verlet + vvx*dt + 0.5*aax*(dt^2);
    yy_verlet = yy_verlet + vvy*dt + 0.5*aay*(dt^2);
    aax = -(k/m)*vv*vvx;
    aay = -g -(k/m)*vv*vvy;
    
    %Update parameter store
    t = [t,tt];
    x = [x,xx];
    x_verlet = [x_verlet,xx_verlet];
    y = [y,yy];
    y_verlet = [y_verlet,yy_verlet];
    vx = [vx,vvx];
    vy= [vy,vvy];
    v = [v,vv];
    ax = [ax,aax];
    ay = [ay,aay];
    
    %Update stopping criteia
    n = n + 1;
    stop_condition = ( (tt>0) && (yy<0)  ) || (n>N);
end

%Determine drag-free trajectory. 
%Firstly find time of flight such that y = 0.
a = -0.5*g;
b = u*sin(theta);
c = h;
t1 = ( -b + sqrt( b^2 - 4*a*c ) )/(2*a);
t2 = ( -b - sqrt( b^2 - 4*a*c ) )/(2*a);
tof = max([t1,t2]);
T = linspace(0,tof,N);
x_nodrag = u*cos(theta)*T;
y_nodrag = u*sin(theta)*T - 0.5*g*(T.^2) + h;
vx_nodrag = u*cos(theta);
vy_nodrag = u*sin(theta) - g*T;
ax_nodrag = zeros(1,N);
ay_nodrag = -g*ones(1,N);

%%

%Create a figure window and plot curves
fig = figure( 'color', [1 1 1],'name','Projectile with drag' );

%x vs y curve
plot( x, y, x_verlet, y_verlet ,x_nodrag, y_nodrag );
xlabel('x/m','fontsize',fsize);
ylabel('y/m','fontsize',fsize);
legend({'drag','drag verlet','no drag'})
title({['Projectile with drag: u = ',num2str(u),'ms^{-1}, \theta = ',...
    num2str(theta*180/pi),'^o, h = ',num2str(h),'m'],...
    ['\rho = ',num2str(rho),' kgm^{-3}, A = ',num2str(A),'m^2, m = ',...
    num2str(m),'kg, c_D = ',num2str(cD)]},'fontsize',fsize);
xlim([0,max([x(end),x_nodrag(end)])])
ylims = get(gca,'ylim');
ylim([0,ylims(2)])
grid on
set(gca,'fontsize',fsize)
print( fig, 'projectile_with_drag x vs y.png','-dpng','-r300' );
cla;

%vx and vy vs t curve
plot( t,vx,'r-', t,vy,'b-', T,vx_nodrag,'r--', T,vy_nodrag,'b--' );
xlabel('t/s','fontsize',fsize);
ylabel('velocity /ms^{-1}','fontsize',fsize);
legend({'vx','vy','vx no drag','vy no drag'})
title({['Projectile with drag: u = ',num2str(u),'ms^{-1}, \theta = ',...
    num2str(theta*180/pi),'^o, h = ',num2str(h),'m'],...
    ['\rho = ',num2str(rho),' kgm^{-3}, A = ',num2str(A),'m^2, m = ',...
    num2str(m),'kg, c_D = ',num2str(cD)]},'fontsize',fsize);
axis tight
xlim([0,min([tof,t(end)])])
grid on
set(gca,'fontsize',fsize)
print( fig, 'projectile_with_drag vx vy vs t.png','-dpng','-r300' );
cla;

%ax and ay vs t curve
plot( t,ax,'r-', t,ay,'b-', T, ax_nodrag,'r--', T, ay_nodrag,'b--' );
xlabel('t/s','fontsize',fsize);
ylabel('aceleration /ms^{-2}','fontsize',fsize);
legend({'ax','ay','ax no drag','ay no drag'})
title({['Projectile with drag: u = ',num2str(u),'ms^{-1}, \theta = ',...
    num2str(theta*180/pi),'^o, h = ',num2str(h),'m'],...
    ['\rho = ',num2str(rho),' kgm^{-3}, A = ',num2str(A),'m^2, m = ',...
    num2str(m),'kg, c_D = ',num2str(cD)]},'fontsize',fsize);
axis tight
ylims = get( gca, 'ylim' );
set( gca, 'ylim', [ylims(1), 1] );
xlim([0,min([tof,t(end)])])
grid on
set(gca,'fontsize',fsize)
print( fig, 'projectile_with_drag ax ay vs t.png','-dpng','-r300' );
cla;
close(fig);

%End of code