%stokes
% Model which plots v vs t and x vs t curves for the descent of a small
% sphere in a column of viscous fluid. Drag force is assumed to follow
% Stokes' Law, i.e. proportional to velocity.
%
% LAST UPDATED by Andy French January 2016

function stokes

% Define Inputs

% Define dynamic viscosity of fluid /kgm^-1s^-1
% Water is 8.9e-4, castor oil is about 0.99
mu = 1;

%Define radius of sphere /cm, the convert to metres
r = 0.5;
r = r*1e-2;

%Gravitational field strength /ms^-2
g = 9.81;

%Initial velocity /ms^-1
u = 0;

%Mass of sphere /kg
m = 0.01;

%Number of time points
N = 1000;

%Fontsize
fsize = 18;

%%

%Calculate kinematic variables t,x,v,a

%Drag constant k such that drag force is F = k*v
k = 6*pi*mu*r;

%Time array  - stop when kt/m = 5
tstop = 5*m/k;
t = linspace(0,tstop,N);

%Velocity /ms^-1
v = m*g/k - (m*g/k - u )*exp(-k*t/m);

%Displacement /m
x = m*g*t/k - (m/k)*( m*g/k - u )*(1- exp(-k*t/m) );

%Acceleration /ms^-2
a = g - k*v/m;

%%

%Create a figure window and plot curves
fig = figure( 'color', [1 1 1],'name','Stokes drag' );
plot( t, x );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('x/m','fontsize',fsize);
title(['Stokes drag: \mu = ',...
    num2str(mu),' kgm^{-1}s^{-1}, r = ',...
    num2str(r),'m, m = ',num2str(m),'kg'],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'stokes x vs t.png','-dpng','-r300' );
cla;
plot( t, v );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('v/ms^{-2}','fontsize',fsize);
title(['Stokes drag: \mu = ',...
    num2str(mu),' kgm^{-1}s^{-1}, r = ',...
    num2str(r),'m, m = ',num2str(m),'kg'],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'stokes v vs t.png','-dpng','-r300' );
plot( t, a );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('a/ms^{-2}','fontsize',fsize);
title(['Stokes drag: \mu = ',...
    num2str(mu),' kgm^{-1}s^{-1}, r = ',...
    num2str(r),'m, m = ',num2str(m),'kg'],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'stokes a vs t.png','-dpng','-r300' );
close(fig);

%End of code