%v_squared_drag
% Model which plots v vs t and x vs t curves for the descent of an object
% at moderate speeds through air e.g. a parachutist
%
% LAST UPDATED by Andy French January 2016

function v_squared_drag

% Define Inputs

% Define density of fluid /kgm^-3
rho = 1;

%Define cross sectional area of falling object /m^2
A = 10;

%Drag coefficient
cD = 0.1;

%Gravitational field strength /ms^-2
g = 9.81;

%Initial velocity /ms^-1
u = 0;

%Mass of falling object /kg
m = 80;

%Number of time points
N = 1000;

%Fontsize
fsize = 18;

%%

%Calculate kinematic variables t,x,v,a

%Drag constant k such that drag force is F = k*v^2
k = 0.5*cD*rho*A;

%Time array  - stop when gt = sqrt(m*g/k) 
tstop = 5*sqrt( m/(g*k) );
t = linspace(0,tstop,N);

%Velocity /ms^-1
v = sqrt(m*g/k)*tanh( sqrt(k/(m*g))*g*t + atanh( u*sqrt(k/(m*g)) ) );

%Displacement /m
x = (m/k)*log( cosh( sqrt(k/(m*g))*g*t + atanh( u*sqrt(k/(m*g)) ) )./...
    cosh( atanh( u*sqrt(k/(m*g)) ))  );

%Check v vs x works
v_check = sqrt( m*g/k ) * sqrt( -( 1 - (k*u^2)/(m*g) )*exp(-2*k*x/m) + 1 );

%Acceleration /ms^-2
a = g - k*(v.^2)/m;

%%

%Create a figure window and plot curves
fig = figure( 'color', [1 1 1],'name','Stokes drag' );
plot( t, x );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('x/m','fontsize',fsize);
title(['v^2 drag drag: \rho = ',...
    num2str(rho),' kgm^{-3}, A = ',...
    num2str(A),'m^2, m = ',num2str(m),'kg, c_D = ',num2str(cD)],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'v_squared_drag x vs t.png','-dpng','-r300' );
cla;
plot( t, v );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('v/ms^{-2}','fontsize',fsize);
title(['v^2 drag drag: \rho = ',...
    num2str(rho),' kgm^{-3}, A = ',...
    num2str(A),'m^2, m = ',num2str(m),'kg, c_D = ',num2str(cD)],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'v_squared_drag v vs t.png','-dpng','-r300' );
cla;
plot( t, a );
xlim([0,tstop])
xlabel('t/s','fontsize',fsize);
ylabel('a/ms^{-2}','fontsize',fsize);
title(['v^2 drag drag: \rho = ',...
    num2str(rho),' kgm^{-3}, A = ',...
    num2str(A),'m^2, m = ',num2str(m),'kg, c_D = ',num2str(cD)],'fontsize',fsize);
grid on
set(gca,'fontsize',fsize)
print( fig, 'v_squared_drag a vs t.png','-dpng','-r300' );
plot( x, v, x, v_check );
hold on;
%plot( x, ones(1,N)*sqrt( m*g/k ),'r-')
legend({'x(t) vs v(t)','x(t) vs v(x)'})
xlabel('x/m','fontsize',fsize);
ylabel('v/ms^{-1}','fontsize',fsize);
title(['v^2 drag drag: \rho = ',...
    num2str(rho),' kgm^{-3}, A = ',...
    num2str(A),'m^2, m = ',num2str(m),'kg, c_D = ',num2str(cD)],'fontsize',fsize);
axis tight
grid on
set(gca,'fontsize',fsize)
print( fig, 'v_squared_drag x vs v.png','-dpng','-r300' );
close(fig);

%End of code